﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Drawing;

using Color = System.Drawing.Color;
using Brush = MindFusion.Drawing.Brush;
using SolidBrush = MindFusion.Drawing.SolidBrush;

namespace FunnelChart
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			var values = new List<double>() { 70, 60, 50, 30, 20, 15, 10, 4 };
			var labels = new List<string>()
			{
				"Unqualified prospects",
				"Leads",
				"Initial communication",
				"Customer evaluation",
				"Negotiation",
				"Purchase order received",
				"Delivery",
				"Payment"
			};
			var legendLabels = new List<string>()
			{
				"Unqualified prospects=70K, 100%",
				"Leads=60K, 85.7%",
				"Initial communication=50K, 71.4%",
				"Customer evaluation=30K, 42.9%",
				"Negotiation=20K, 28.6%",
				"Purchase order received=15K, 21.4%",
				"Delivery=10K, 14.3%",
				"Payment=4K, 5.7%"
			};

			funnelChart.Series = new BarSeries(values, labels, legendLabels);

			var brushes = new List<Brush>()
			{
				 new SolidBrush(ColorTranslator.FromHtml("#669acc")),
				 new SolidBrush(ColorTranslator.FromHtml("#616a7f")),
				 new SolidBrush(ColorTranslator.FromHtml("#e0e9e9")),
				 new SolidBrush(ColorTranslator.FromHtml("#003466")),
				 new SolidBrush(ColorTranslator.FromHtml("#c0c0c0")),
				 new SolidBrush(ColorTranslator.FromHtml("#ce0000")),
				 new SolidBrush(ColorTranslator.FromHtml("#9caac6")),
				 new SolidBrush(ColorTranslator.FromHtml("#000063"))
			};

			var strokes = new List<Brush>(){
				new SolidBrush(ColorTranslator.FromHtml("#FFFFFF"))};

			var seriesBrushes = new List<List<Brush>>();
			seriesBrushes.Add(brushes);
			var seriesStrokes = new List<List<Brush>>();
			seriesStrokes.Add(strokes);
			var thicknesses = new List<double>() { 6 };
			var seriesThicknesses = new List<List<double>>();
			seriesThicknesses.Add(thicknesses);

			funnelChart.Plot.SeriesStyle = new PerElementSeriesStyle(seriesBrushes, seriesStrokes, seriesThicknesses, null);

			funnelChart.Theme.DataLabelsFontSize = 12;
			funnelChart.Theme.HighlightStroke = new SolidBrush(ColorTranslator.FromHtml("#ce0000"));

			funnelChart.LegendRenderer.Background = new SolidBrush(ColorTranslator.FromHtml("#e0e9e9"));
			funnelChart.LegendRenderer.BorderStroke = new SolidBrush(ColorTranslator.FromHtml("#c0c0c0"));
			funnelChart.LegendRenderer.ElementLabelKind = LabelKinds.OuterLabel;
			funnelChart.LegendRenderer.TitleFontSize = 14.0;
			funnelChart.LegendVerticalAlignment = LayoutAlignment.Far;

			tbSegmentSpacing.Value = funnelChart.SegmentSpacing;
			tbStemWidth.Value = (int)(funnelChart.StemWidth*100);
		}

		void chbShowLegend_CheckedChanged(object sender, EventArgs e)
		{
			funnelChart.ShowLegend = !funnelChart.ShowLegend;
			funnelChart.Invalidate();
		}

		void chbShowDataLabels_CheckedChanged(object sender, EventArgs e)
		{
			if (chbShowDataLabels.Checked)
				funnelChart.ShowDataLabels = LabelKinds.All;
			else
				funnelChart.ShowDataLabels = LabelKinds.None;
			funnelChart.Invalidate();
		}

		private void tbSegmentSpacing_Scroll(object sender, EventArgs e)
		{
			funnelChart.SegmentSpacing = tbSegmentSpacing.Value;
		}

		private void tbStemWidth_Scroll(object sender, EventArgs e)
		{
			funnelChart.StemWidth = (float)tbStemWidth.Value/100;
		}

		private void tbWidth_Scroll(object sender, EventArgs e)
		{
			funnelChart.Plot.Width = tbWidth.Value;
		}

		private void tbHeight_Scroll(object sender, EventArgs e)
		{
			funnelChart.Plot.Height = tbHeight.Value;
		}
	}
}